instrumenttools.BassFlute
=========================

.. abjad-lineage:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute

.. autoclass:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassFlute.BassFlute.BassFlute.__repr__
   :noindex:
